@@ -4,7 +4,7 @@
 # Pod stripped from pm file by OODoc 2.01.
 package Apache::Solr::JSON;
 use vars '$VERSION';
-$VERSION = '0.94';
+$VERSION = '0.95';
 
 use base 'Apache::Solr';
 
@@ -45,7 +45,7 @@ sub _select($)
 
     my $endpoint = $self->endpoint('select', params => \@params);
     my $result   = Apache::Solr::Result->new(params => \@params
-      , endpoint => $endpoint);
+      , endpoint => $endpoint, core => $self);
     $self->request($endpoint, $result);
 
     if(my $dec = $result->decoded)
@@ -61,7 +61,7 @@ sub _extract($$$)
     my @params   = (wt => 'json', @$params);
     my $endpoint = $self->endpoint('update/extract', params => \@params);
     my $result   = Apache::Solr::Result->new(params => \@params
-      , endpoint => $endpoint);
+      , endpoint => $endpoint, core => $self);
     $self->request($endpoint, $result, $data, $ct);
     $result;
 }
@@ -80,7 +80,7 @@ sub _add($$$)
       , params => \@params
       );
     my $result   = Apache::Solr::Result->new(params => \@params
-      , endpoint => $endpoint);
+      , endpoint => $endpoint, core => $self);
 
     # We cannot create HASHes with twice the same key in Perl, so cannot
     # produce the syntax for adding multiple documents.  Try to save it.
@@ -133,7 +133,7 @@ sub _terms($)
     my @params   = (wt => 'json', @$terms);
     my $endpoint = $self->endpoint('terms', params => \@params);
     my $result   = Apache::Solr::Result->new(params => \@params
-      , endpoint => $endpoint);
+      , endpoint => $endpoint, core => $self);
 
     $self->request($endpoint, $result);
 
@@ -192,7 +192,7 @@ sub simpleUpdate($$;$)
       , params => \@params
       );
     my $result   = Apache::Solr::Result->new(params => \@params
-      , endpoint => $endpoint);
+      , endpoint => $endpoint, core => $self);
 
     my %params   = (%$attrs
       , (!$content ? () : ref $content eq 'HASH' ? %$content : @$content));
